.. _spkg_zftools:

zftools: Find the zero forcing set of graphs
============================================

Description
-----------

Find the zero forcing set of graphs

License
-------

GPLv3

Upstream Contact
----------------

- https://pypi.org/project/zftools/
- https://github.com/passagemath/passagemath-pkg-zftools


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_sagemath_graphs`
- :ref:`spkg_sagemath_repl`

Version Information
-------------------

requirements.txt::

    zftools @ git+https://github.com/passagemath/passagemath-pkg-zftools.git

Equivalent System Packages
--------------------------

(none known)
